@@ -55,6 +55,13 @@ gcc_prefix() {
     esac
 }
 
+is_musl() {
+    case "$TARGET" in
+        *-musl) return 0 ;;
+        *)      return 1 ;;
+    esac
+}
+
 is_x86() {
     case "$(architecture)" in
       amd64|i386) return 0 ;;
@@ -62,6 +69,13 @@ is_x86() {
     esac
 }
 
+is_x86_64() {
+    case "$(architecture)" in
+      amd64) return 0 ;;
+      *)          return 1 ;;
+    esac
+}
+
 is_arm() {
     case "$(architecture)" in
         armhf) return 0 ;;
@@ -82,3 +96,14 @@ is_osx() {
         *)   return 1 ;;
     esac
 }
+
+builder() {
+    if is_musl && is_x86_64; then
+        # cargo install cross
+        # To work around https://github.com/rust-embedded/cross/issues/357
+        cargo install --git https://github.com/rust-embedded/cross --force
+        echo "cross"
+    else
+        echo "cargo"
+    fi
+}
