@@ -1,5 +1,5 @@
 use crate::hay::SHERLOCK;
-use crate::util::{Dir, TestCommand, cmd_exists, sort_lines};
+use crate::util::{cmd_exists, sort_lines, Dir, TestCommand};
 
 // This file contains "miscellaneous" tests that were either written before
 // features were tracked more explicitly, or were simply written without
@@ -65,8 +65,10 @@ rgtest!(with_heading, |dir: Dir, mut cmd: TestCommand| {
     cmd.args(&[
         // This forces the issue since --with-filename is disabled by default
         // when searching one file.
-        "--with-filename", "--heading",
-        "Sherlock", "sherlock",
+        "--with-filename",
+        "--heading",
+        "Sherlock",
+        "sherlock",
     ]);
 
     let expected = "\
@@ -184,9 +186,7 @@ be, to a very large extent, the result of luck. FooBar Holmes
 
 rgtest!(replace_groups, |dir: Dir, mut cmd: TestCommand| {
     dir.create("sherlock", SHERLOCK);
-    cmd.args(&[
-        "-r", "$2, $1", "([A-Z][a-z]+) ([A-Z][a-z]+)", "sherlock",
-    ]);
+    cmd.args(&["-r", "$2, $1", "([A-Z][a-z]+) ([A-Z][a-z]+)", "sherlock"]);
 
     let expected = "\
 For the Watsons, Doctor of this world, as opposed to the Sherlock
@@ -199,7 +199,8 @@ but Watson, Doctor has to have it taken out for him and dusted,
 rgtest!(replace_named_groups, |dir: Dir, mut cmd: TestCommand| {
     dir.create("sherlock", SHERLOCK);
     cmd.args(&[
-        "-r", "$last, $first",
+        "-r",
+        "$last, $first",
         "(?P<first>[A-Z][a-z]+) (?P<last>[A-Z][a-z]+)",
         "sherlock",
     ]);
@@ -279,9 +280,7 @@ rgtest!(file_type_add, |dir: Dir, mut cmd: TestCommand| {
     dir.create("file.py", "Sherlock");
     dir.create("file.rs", "Sherlock");
     dir.create("file.wat", "Sherlock");
-    cmd.args(&[
-        "--type-add", "wat:*.wat", "-t", "wat", "Sherlock",
-    ]);
+    cmd.args(&["--type-add", "wat:*.wat", "-t", "wat", "Sherlock"]);
 
     eqnice!("file.wat:Sherlock\n", cmd.stdout());
 });
@@ -292,9 +291,12 @@ rgtest!(file_type_add_compose, |dir: Dir, mut cmd: TestCommand| {
     dir.create("file.rs", "Sherlock");
     dir.create("file.wat", "Sherlock");
     cmd.args(&[
-        "--type-add", "wat:*.wat",
-        "--type-add", "combo:include:wat,py",
-        "-t", "combo",
+        "--type-add",
+        "wat:*.wat",
+        "--type-add",
+        "combo:include:wat,py",
+        "-t",
+        "combo",
         "Sherlock",
     ]);
 
@@ -392,6 +394,28 @@ rgtest!(count_matches_via_only, |dir: Dir, mut cmd: TestCommand| {
     eqnice!(expected, cmd.stdout());
 });
 
+rgtest!(include_zero, |dir: Dir, mut cmd: TestCommand| {
+    dir.create("sherlock", SHERLOCK);
+    cmd.args(&["--count", "--include-zero", "nada"]);
+    cmd.assert_err();
+
+    let output = cmd.cmd().output().unwrap();
+    let stdout = String::from_utf8_lossy(&output.stdout);
+    let expected = "sherlock:0\n";
+
+    eqnice!(expected, stdout);
+});
+
+rgtest!(include_zero_override, |dir: Dir, mut cmd: TestCommand| {
+    dir.create("sherlock", SHERLOCK);
+    cmd.args(&["--count", "--include-zero", "--no-include-zero", "nada"]);
+    cmd.assert_err();
+
+    let output = cmd.cmd().output().unwrap();
+    let stdout = String::from_utf8_lossy(&output.stdout);
+    assert!(stdout.is_empty());
+});
+
 rgtest!(files_with_matches, |dir: Dir, mut cmd: TestCommand| {
     dir.create("sherlock", SHERLOCK);
     cmd.arg("--files-with-matches").arg("Sherlock");
@@ -487,7 +511,7 @@ rgtest!(context_line_numbers, |dir: Dir, mut cmd: TestCommand| {
     eqnice!(expected, cmd.stdout());
 });
 
-rgtest!(max_filesize_parse_errro_length, |_: Dir, mut cmd: TestCommand| {
+rgtest!(max_filesize_parse_error_length, |_: Dir, mut cmd: TestCommand| {
     cmd.arg("--max-filesize").arg("44444444444444444444");
     cmd.assert_non_empty_stderr();
 });
@@ -946,6 +970,21 @@ be, to a very large extent, the result of luck. Sherlock Holmes
     eqnice!(expected, cmd.stdout());
 });
 
+rgtest!(compressed_uncompress, |dir: Dir, mut cmd: TestCommand| {
+    if !cmd_exists("uncompress") {
+        return;
+    }
+
+    dir.create_bytes("sherlock.Z", include_bytes!("./data/sherlock.Z"));
+    cmd.arg("-z").arg("Sherlock").arg("sherlock.Z");
+
+    let expected = "\
+    For the Doctor Watsons of this world, as opposed to the Sherlock
+be, to a very large extent, the result of luck. Sherlock Holmes
+";
+    eqnice!(expected, cmd.stdout());
+});
+
 rgtest!(compressed_failing_gzip, |dir: Dir, mut cmd: TestCommand| {
     if !cmd_exists("gzip") {
         return;
